Crate newrelic_sdk

Functions

init
segment_end
Identify the end of a segment
segment_external_begin
Identify the beginning of a segment that performs an external service.
segment_external_with
segment_generic_begin
Identify the beginning of a segment that performs a generic operation.
segment_generic_with
transaction_begin
Identify the beginning of a transaction.
transaction_end
Identify the end of a transaction
transaction_notice_error
Identify an error that occurred during the transaction. The first identified error is sent with each transaction.
transaction_set_name
Set a name for the transaction
transaction_with