Functions
- init
- segment_
end - Identify the end of a segment
- segment_
external_ begin - Identify the beginning of a segment that performs an external service.
- segment_
external_ with - segment_
generic_ begin - Identify the beginning of a segment that performs a generic operation.
- segment_
generic_ with - transaction_
begin - Identify the beginning of a transaction.
- transaction_
end - Identify the end of a transaction
- transaction_
notice_ error - Identify an error that occurred during the transaction. The first identified error is sent with each transaction.
- transaction_
set_ name - Set a name for the transaction
- transaction_
with